<?php

class WP_Analytify_Email extends WP_Analytify_Pro_Base{


	function __construct() {

		parent::__construct();
		$this->setup_constants();
		$this->hooks();

		if ( isset( $_POST['test_email'] ) ) {

			$this->callback_on_cron_time();
			add_action( 'admin_notices', array( $this , 'analytify_email_notics' ) );
		}

	}

	function hooks() {

		add_action( 'admin_init', array( $this, '_plugin_updater' ), 0 );

		add_action( 'admin_enqueue_scripts' , array( $this, 'analytify_email_scripts' ) );
		add_action( 'analyitfy_email_setting_submenu', array( $this, 'email_submenu' ), 25 );
		// For Custom Timing in Cron Job
		add_filter( 'cron_schedules', array( $this, 'custom_cron_job_time' ) );
		add_action( 'analytify_email_cron_function', array( $this, 'callback_on_cron_time' ) );

		// add_action( 'phpmailer_init', array( $this , 'custom_phpmailer_init' ) );

  	add_action( 'wp_analytify_email_license_key', 	array( $this, 'display_license_form' ) );

		add_action( 'wp_analytify_pro_setting_tabs' , array( $this, 'analytify_email_setting_tabs' ) , 20 , 1 );
		add_filter( 'wp_analytify_pro_setting_fields', array( $this, 'analytifye_email_setting_fields' ) , 20, 1 );

		add_action( 'init', array( $this, 'anaytify_email_check_time' ) );
		add_action( 'wp_ajax_wpanalytifyemail_activate_license', array( $this, 'ajax_activate_license' ) );

		add_action( 'after_single_view_stats_buttons', array( $this, 'single_send_email' ) );
		add_action( 'wp_ajax_send_analytics_email', array( $this, 'send_analytics_email' ) );
	}

	/**
	 * Update your plugin from our own server.
	 *
	 * @since 1.0.0
	 */
	function _plugin_updater() {

		// retrieve our license key from the DB
		$_license_key = trim( get_option( 'analytify_email_license_key' ) );

		// setup the updater
		if ( class_exists( 'ANALYTIFY_SL_Plugin_Updater' ) ) {
			$edd_updater = new ANALYTIFY_SL_Plugin_Updater( EMAIL_ANALYTIFY_STORE_URL, ANALYTIFY_EMAIL_UPGRADE_PATH, array(
				'version'   => ANALTYIFY_EMAIL_VERSION,               // current version number
				'license'   => $_license_key,        // license key (used get_option above to retrieve from DB)
				'item_id' => EMAIL_ANALYTIFY_PRODUCT_ID,    // name of this plugin
				'author'    => 'Muhammad Adnan',// author of this plugin
			)	);
		}
	}


	/**
	 * Enqueue Scripts
	 *
	 * @since 1.0
	 */
	function analytify_email_scripts() {

		wp_enqueue_script( 'analytify_email_script', plugins_url( 'assets/js/main.js' , __FILE__ ), array(), ANALTYIFY_EMAIL_VERSION, 'true' );

	}

	function email_submenu() {

		add_submenu_page( 'analytify-dashboard', ANALYTIFY_NICK . esc_html__( 'Email Notifications', 'wp-analytify-email' ), esc_html__( 'Email Notifications', 'wp-analytify-email' ), 'manage_options', 'analytify-settings#wp-analytify-email', array( $this, 'analytify_email_setting' ) );
	}

	function analytify_email_setting(){

	}

	/**
	 * Setup plugin constants
	 *
	 * @access      private
	 * @since       1.0.0
	 * @return      void
	 */
	private function setup_constants() {

		// Setting Global Values
		$this->define( 'EMAIL_ANALYTIFY_PLUGIN_FILE', __FILE__ );
		$this->define( 'EMAIL_ANALYTIFY_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
		$this->define( 'EMAIL_ANALYTIFY_PLUGIN_DIR', dirname( __FILE__ ) );
		$this->define( 'EMAIL_ANALYTIFY_PRODUCT_NAME', "Google Analytics Email Notifications" );
		$this->define( 'EMAIL_ANALYTIFY_PRODUCT_ID', 6580 );
		$this->define( 'EMAIL_ANALYTIFY_STORE_URL', "https://analytify.io" );

	}

	/**
	 * Define constant if not already set
	 * @param  string $name
	 * @param  string|bool $value
	 */
	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Change Cron Job Time
	 *
	 * @param  array $schedules
	 * @return array
	 * @since 1.0
	 */
	function custom_cron_job_time( $schedules ) {

		if ( ! array_key_exists( 'weekly', $schedules ) ) {
			$schedules['weekly'] = array(
			'interval' => 604800,
			'display'  => __( 'Once Weekly', 'wp-analytify-email' ),
			);
		}

		if ( ! array_key_exists( 'biweekly', $schedules ) ) {
			$schedules['biweekly'] = array(
			'interval' => 1209600,
			'display'  => __( 'Once Every 2 Weeks', 'wp-analytify-email' ),
			);
		}

		if ( ! array_key_exists( '4weeks', $schedules ) ) {
			$schedules['4weeks'] = array(
			'interval' => 2419200,
			'display'  => __( 'Once Every 4 Weeks', 'wp-analytify-email' ),
			);
		}

		return $schedules;
	}

	function anaytify_email_check_time() {

		// unschedule previos event if time change form setting
		if ( wp_get_schedule( 'analytify_email_cron_function' ) !== $GLOBALS['WP_ANALYTIFY']->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) ) {

			wp_clear_scheduled_hook( 'analytify_email_cron_function' );
		}

		// check if event scheduled before
		if ( ! wp_next_scheduled( 'analytify_email_cron_function' ) ) {

			$time = '';
			// shedule event to run after every hour
			if ( $GLOBALS['WP_ANALYTIFY']->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'weekly' ) {
				$time  = time( 604800 );
			} else if ( $GLOBALS['WP_ANALYTIFY']->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'biweekly' ) {
				$time  = time( 1209600 );

			} else if ( $GLOBALS['WP_ANALYTIFY']->settings->get_option( 'analytif_email_cron_time','wp-analytify-email'  ) == '4weeks' ) {
				$time  = time( 2419200 );
			}
			wp_schedule_event( $time , $GLOBALS['WP_ANALYTIFY']->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ), 'analytify_email_cron_function' );

		}

	}

	function analytify_email_setting_tabs( $old_tabs ) {

		$pro_tabs = array(
			array(
				'id'       => 'wp-analytify-email',
				'title'    => __( 'Email', 'wp-analytify-email' ),
				'priority' => '30',
			),
		);

		return array_merge( $old_tabs,$pro_tabs );
	}

	function  analytify_email_notics() { ?>
		<div class="notice notice-success is-dismissible">
			<p><?php _e( 'Analytify detailed report sent!', 'wp-analytify-email' ); ?></p>
		</div>
		<?php }



	function custom_phpmailer_init( $PHPMailer ) {
		$PHPMailer->IsSMTP();
		$PHPMailer->SMTPAuth = true;
		$PHPMailer->SMTPSecure = 'ssl';
		$PHPMailer->Host = 'smtp.gmail.com';
		$PHPMailer->Port = 465;
		$PHPMailer->Username = 'test@gmail.com';
		$PHPMailer->Password = '';
	}


	function analytifye_email_setting_fields( $old_fields ) {
		$pro_fields = array(
			'wp-analytify-email' => array(
				array(
					'name'              => 'analytiy_from_name',
					'label'             => __( 'From Name', 'wp-analytify-email' ),
					'desc'              => __( 'Sender Name.', 'wp-analytify-email' ),
					'type'              => 'text',
					'default'           => '',
					'sanitize_callback' => 'sanitize_text_field',
				),
				array(
					'name'              => 'analytiy_from_email',
					'label'             => __( 'From Email', 'wp-analytify-email' ),
					'desc'              => __( 'Sender Email.', 'wp-analytify-email' ),
					'type'              => 'text',
					'default'           => '',
					'sanitize_callback' => 'sanitize_email',
				),
				array(
					'name'              => 'analytify_email_user_email',
					'label'             => __( 'To Email Address:', 'wp-analytify-email' ),
					'desc'              => __( 'Use commas to add more than 1 Email', 'wp-analytify-email' ),
					'type'              => 'text',
					'default'           => '',
					'sanitize_callback' => 'sanitize_text_field',
				),
				array(
					'name'              => 'analytify_email_stats',
					'label'             => __( 'Select Email Stats:', 'wp-analytify-email' ),
					'desc'              => __( 'Select which Stats panels you want to display in Email. ', 'wp-analytify-email' ),
					'type'              => 'chosen',
					'default' 					=> array(),
					'options' => array(
						'show-overall-general' => analytify__( 'General Stats', 'wp-analytify' ),
						'show-top-pages'       => __( 'Top Pages Stats', 'wp-analytify-email' ),
						'show-geographics'     => analytify__( 'Geographic Stats', 'wp-analytify' ),
						'show-system'          => analytify__( 'System Stats', 'wp-analytify' ),
						'show-keywords'        => analytify__( 'Keywords Stats', 'wp-analytify' ),
						'show-social'          => analytify__( 'Social Media Stats', 'wp-analytify' ),
						'show-whats-happen'    => __( 'Whats Happening Stats', 'wp-analytify-email' ),
					),
				),
				array(
					'name'    				=> 'analytif_email_cron_time',
					'label'   				=> __( 'Select Time:', 'wp-analytify-email' ),
					'desc'   				  => __( 'Email sent automatically to user after selected time', 'wp-analytify-email' ),
					'type'    				=> 'select',
					'default' 				=> 'weekly',
					'options' => array(
						'weekly'   => __( 'Every Week', 'wp-analytify-email' ),
						'biweekly' => __( 'Every 2 Weeks', 'wp-analytify-email' ),
						'4weeks'   => __( 'Every Month', 'wp-analytify-email' ),
					),
				),
				array(
					'name'              => 'analytify_email_logo',
					'label'             => __( 'Your Agency Logo:', 'wp-analytify-email' ),
					'desc'              => __( 'Add your Agency logo in Email Template.<br />Prefered size 150*150 pixel', 'wp-analytify-email' ),
					'type'              => 'image',
					'default'           => '',
					'sanitize_callback' => '',
				),
				array(
					'name'              => 'analytify_go_to_dashboard',
					'label'             => __( 'Hide \'Go To Dashboard\' Button:', 'wp-analytify-email' ),
					'desc'              => __( 'Check this if you want to hide the Go To Dashboard button', 'wp-analytify-email' ),
					'type'              => 'checkbox'
				),
			),
		);

	return array_merge( $old_fields, $pro_fields );

	}


	/*
	 * Output Email Notifications license activation key fields/inputs
	 * @access public
	 *
     */
    function display_license_form() {

	    $license_email  = get_option( 'analytify_email_license_key' );
	    $status_email   = get_option( 'analytify_email_license_status' );

	    ?>
	    <tr><th></th><td><hr style="width: 50%; float: left;" /></td></tr>
	    <tr valign="top">
	    	<th scope="row" valign="top">
	    	<?php esc_html_e( 'Email Notifications (License Key):', 'wp-analytify-email' ); ?>
	    	</th>

	    	<?php  if( 'valid' === $status_email ) : ?>

	        <td class="email-license-row">

	        <?php echo $this->get_formatted_masked_email_license( $license_email ); ?>

	        </td>

	    	<?php else : ?>

	        <td class="email-license-row">
	        <input id="analytify_email_license_key" name="analytify_email_license_key" type="text" class="regular-text" value="<?php esc_attr_e( $license_email ); ?>" />

	        <input type="submit" class="button-secondary" id="analytify_email_license_activate" name="analytify_license_activate" value="<?php esc_html_e( 'Activate License', 'wp-analytify-email' ); ?>"/>

	        <br /><p id="email-license-status"><?php if( $status_email ) echo $status_email; ?></p>

	        </td>

	    	<?php endif; ?>

	    </tr>

	    <?php

    }

	/**
	 *
	 * Send Ajax on Active license.
	 *
	 * @since 1.0.0
	 */
	public function ajax_activate_license() {

		$this->check_ajax_referer( 'activate-license' );

		$key_rules = array(
		'action'            => 'key',
		'email_license_key' => 'string',
		'context'           => 'key',
		'nonce'             => 'key',
		);
		$this->set_post_data( $key_rules );

		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => $this->state_data['email_license_key'],
			'item_id'  => EMAIL_ANALYTIFY_PRODUCT_ID, // the name of our product in EDD
			'url'        => home_url(),
		);

		$response = wp_remote_get( esc_url_raw( add_query_arg( $api_params, EMAIL_ANALYTIFY_STORE_URL ) ), array( 'timeout' => 30, 'sslverify' => false ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) ) {
			return false;
		}



		$license_response = json_decode( wp_remote_retrieve_body( $response ) );

		if ( 'valid' === $license_response->license ) {
			$this->set_email_license_key( $this->state_data['email_license_key'] );
			$license_response->masked_license = $this->get_formatted_masked_email_license( $this->state_data['email_license_key'] );
		} else {

			if ( 'invalid' === $license_response->license ) {

				set_site_transient( 'wpanalytify_email_license_response', $license_response, $this->transient_timeout );
				$license_response->error = $this->get_email_license_status_message( $license_response, $this->state_data['context'] );

			}
		}
		// print_r($license_response);
		// wp_die();
		// $license_response->license will be either "valid" or "invalid"
		update_option( 'analytify_email_license_status', $license_response->license );
		update_option( 'analytify_email_license_key' , $this->state_data['email_license_key'] );

		$result = $this->end_ajax( json_encode( $license_response ) );

		return $result;
	}


	function callback_on_cron_time() {

		$Analytify_Email = $GLOBALS['WP_ANALYTIFY'];
		$site_url = site_url();

		if( $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'weekly' ) {
				$start_date_val = strtotime( '-1 week' );

		} else if (  $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'biweekly' ) {
			$start_date_val = strtotime( '-2 week' );

		} else if (  $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == '4weeks' ) {
			$start_date_val = strtotime( '-1 month' );
		}


		$end_date_val        = strtotime( 'now' );
		$start_date          = date( 'Y-m-d', $start_date_val );
		$end_date            = date( 'Y-m-d', $end_date_val );

		$date1               = date_create( $start_date );
		$date2               = date_create( $end_date );
		$diff                = date_diff( $date2, $date1 );
		$different           = $diff->format("%a") . ' ' . analytify__( 'days' , 'wp-analytify' ) ;

		$compare_start_date  = strtotime( $start_date. $diff->format("%R%a days") );
		$compare_start_date  = date( 'Y-m-d', $compare_start_date );
		$compare_end_date 	 = $start_date;

		$_logo_id  = $Analytify_Email->settings->get_option( 'analytify_email_logo','wp-analytify-email' );
		if ( $_logo_id ) {
			$_logo_link_array =  wp_get_attachment_image_src( $_logo_id, array( 150, 150 ) );
			$logo_link = $_logo_link_array[0];
		} else {
			$logo_link = ANALYTIFY_IMAGES_PATH . "logo.png";
		}

		$message = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
			<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
			    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
			        <meta name="viewport" content="width=device-width, initial-scale=1"/>
			    <title>Analytify</title>
			    <link href="https://fonts.googleapis.com/css?family=Roboto%7cRoboto+Slab:400,700" rel="stylesheet"/>
			    <style type="text/css">
			    	@media screen and (max-width: 620px) {
			    	    .main-table{
				    		width: 100% !important;
				    	}
			    	}
			    	@media screen and (max-width: 560px) {
				    	.box-table>tbody>tr>td{
				    		width: 100% !important;
				    		display: block !important;
				    		margin-bottom: 10px !important;
				    	}
				    	.session-table>table{
				    		display: block !important;
				    		width: 100% !important;
				    	}
				    	.session-table>table>tbody{
				    		display: block !important;
				    		width: 100% !important;
				    	}
				    	.session-table>table>tbody>tr{
				    		display: block !important;
				    		width: 96% !important;
				    		margin: 10px 2% 10px !important;
				    	}
				    	.os-table>td, .keywords-table>td{
				    		display: block;
				    		width: 100% !important;
				    	}
				    	.geographic-table>tbody>tr>td{
				    		display: block !important;
				    		width: 100% !important;
				    	}
				    	.user-data>table>tbody>tr>td{
				    		padding:10px !important;
				    	}
				    	.mobile-hide{
				    		display: none !important;
				    	}
				    	.main-table>tbody>tr>td{
				    		padding: 10px !important;
				    	}
				    	.user-data>table>tbody>tr>td img{
				    		margin-left: 0 !important;
				    	}
			    	}

			    </style>
			</head>
			<body style="margin: 0;padding: 0; background: #f1f1f1; " bgcolor="#f1f1f1">
				<table cellpadding="0" cellspacing="0" border="0" width="100%" align="center" bgcolor="#f1f1f1">
					<tr>
						<td valign="top">
							<table cellpadding="0" cellspacing="0" border="0" width="600" align="center" class="main-table">
								<tr>
									<td style="padding: 22px 35px;">
										<table width="100%" cellpadding="0" cellspacing="0" align="center">
											<tr>
												<td align="left"><a href="'. $site_url .'"><img src="'. $logo_link .'" alt=""/></a></td>
												<td align="right" style="font: normal 14px \'Roboto\', Arial, Helvetica, sans-serif;">
												<font color="#848484">' . __( 'Your Analytics Report', 'wp-analytify-email' ) . '</font><br>
												<font color="#444444">' . date( 'M d Y', $start_date_val ) . ' - ' . date( 'M d Y', $end_date_val ) . '</font><br />
												<font color="#444444">'. get_home_url() .'</font>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								<tr>

									<td style="padding: 0 15px;">
										<table width="100%" cellpadding="0" cellspacing="0" align="center">';

								$selectd_stats = 	$Analytify_Email->settings->get_option( 'analytify_email_stats', 'wp-analytify-email' );
							// General Stats.
							if ( is_array( $selectd_stats ) &&  in_array( 'show-overall-general', $selectd_stats )  ) {

								$stats = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions,ga:users,ga:bounceRate,ga:avgTimeOnPage,ga:pageviewsPerSession,ga:pageviews,ga:percentNewSessions,ga:newUsers,ga:avgSessionDuration', $start_date, $end_date );
								$old_stats = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions,ga:users,ga:bounceRate,ga:avgTimeOnPage,ga:pageviewsPerSession,ga:pageviews,ga:percentNewSessions,ga:newUsers,ga:avgSessionDuration', $compare_start_date, $compare_end_date );

								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/general-stats.php';
								$message .= pa_email_include_general( $Analytify_Email, $stats, $old_stats, $different );

							}

							// Top Pages Stats.
							if ( is_array( $selectd_stats ) && in_array( 'show-top-pages', 	$selectd_stats )  ) {

								$stats = $Analytify_Email->pa_get_analytics_dashboard( 'ga:pageviews', $start_date, $end_date, 'ga:PageTitle', '-ga:pageviews', false, 5);
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/top-pages-stats.php';
								$message .= pa_include_top_pages_stats( $Analytify_Email,$stats );

							}

							// Geographic Stats
							if ( is_array( $selectd_stats ) && in_array( 'show-geographics', 	$selectd_stats )  ) {

								$countries = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:country' , '-ga:sessions' , 'ga:country!=(not set)', 5 );
								$cities = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:country,ga:city' , '-ga:sessions' , 'ga:city!=(not set)', 5 );
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/geographic.php';
								$message .= pa_geopgraphic_lisiting( $Analytify_Email, $countries, $cities );

							}

							// System stats
							if ( is_array( $selectd_stats ) && in_array( 'show-system', $selectd_stats )  ) {

								$browers = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:browser' , '-ga:sessions' , false, 5 );
								$operating_systems = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:operatingSystem' , '-ga:sessions' , 'ga:operatingSystem!=(not set)', 5 );
								$mobile_phones = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:mobileDeviceBranding,ga:mobileDeviceModel' , '-ga:sessions' , 'ga:mobileDeviceModel!=(not set);ga:mobileDeviceBranding!=(not set)', 5 );
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/system-stats.php';
								$message .= pa_system_stats( $Analytify_Email, $browers, $operating_systems, $mobile_phones );

							}


							// Keywords
							if ( is_array( $selectd_stats ) && in_array( 'show-keywords', $selectd_stats )  ) {

								$keywords = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:keyword' , '-ga:sessions' , false, 5 );
								$refferals = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:source,ga:medium' , '-ga:sessions' , false, 5 );
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/keyword-referral.php';
								$message .= pa_keyword_referral( $Analytify_Email, $keywords, $refferals );

							}

							// Social Media
							if ( is_array( $selectd_stats ) && in_array( 'show-social', $selectd_stats )  ) {

								$socials = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $start_date, $end_date , 'ga:socialNetwork' , '-ga:sessions' , 'ga:socialNetwork!=(not set)', 5 );
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/social-media.php';
								$message .= social_stats( $Analytify_Email, $socials );

							}

							// Whats Happen
							if ( is_array( $selectd_stats ) && in_array( 'show-whats-happen', $selectd_stats )  ) {

								$whats_happens = $Analytify_Email->pa_get_analytics_dashboard( 'ga:entrances,ga:entranceRate,ga:exits,ga:exitRate', $start_date, $end_date , 'ga:pagePath,ga:pageTitle' , '-ga:entrances' , false, 5 );
								include ANALYTIFY_EMAIL_ROOT_PATH . 'views/whats-happen.php';
								$message .= whats_happen( $Analytify_Email, $whats_happens );

							}

							if ( 'on' !== $Analytify_Email->settings->get_option( 'analytify_go_to_dashboard', 'wp-analytify-email' ) ) {
								$message .= '<tr>
						 									<td style="padding-top: 40px; text-align:center;padding-bottom: 40px;"><a href="'. get_admin_url( null, 'admin.php?page=analytify-dashboard'  ) .'"><img src="'. ANALYTIFY_IMAGES_PATH .'analytify_go_to_dashboard.png" alt="go to dashboard"  /></a></td>
						 								</tr>';
							}


		$message .= '	</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
							</table>
						</body>
						</html>';

		$emails = $Analytify_Email->settings->get_option( 'analytify_email_user_email','wp-analytify-email' );
		$emails_array = explode( ',' , $emails );

		$subject = '';
		if( $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'weekly' ) {
				$subject = __( '1 Week Detailed Report', 'wp-analytify-email' );
		} else if (  $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == 'biweekly' ) {
				$subject = __( '2 Weeks Detailed  Report', 'wp-analytify-email' );
		} else if (  $Analytify_Email->settings->get_option( 'analytif_email_cron_time','wp-analytify-email' ) == '4weeks' ) {
			$subject = __( '1 Month Detailed  Report', 'wp-analytify-email' );
		}

		$_from_name  = $Analytify_Email->settings->get_option( 'analytiy_from_name', 'wp-analytify-email' );
		$_from_name  = ! empty( $_from_name ) ? $_from_name : 'Analytify Notifications';
		$_from_email = $Analytify_Email->settings->get_option( 'analytiy_from_email', 'wp-analytify-email' );
		$_from_email = ! empty( $_from_email ) ? $_from_email : get_option( 'admin_email' );

		$headers = array(
			'From: '. $_from_name . ' <' . $_from_email . '>',
			'Content-Type: text/html; charset=UTF-8'
		);

		wp_mail( $emails_array , $subject, $message, $headers );

	}

	/**
	 * Show Send Email button on Single Page/Post.
	 *
	 * @since 1.2.0s
	 */
	function single_send_email() {

		echo '<input type="submit" value=" '. __( 'Send Email', 'wp-analytify-email' ) .'" name="send_email" class="analytify_submit_date_btn"  id="send_single_analytics">';
		echo "<span  style='min-height:30px;min-width:150px;display:none' class='send_email stats_loading'></span>";
	}

	/**
	 * Send Email Stats for Single Page/Post
	 *
	 * @since 1.2.0
	 */
	function send_analytics_email() {

		$start_date = sanitize_text_field( wp_unslash( $_POST['start_date'] ) );
		$end_date   = sanitize_text_field( wp_unslash( $_POST['end_date'] ) );
		$post_id    = sanitize_text_field( wp_unslash( $_POST['post_id'] ) );
		$site_url   = site_url();

		if ( 0 === $post_id ) {
			$u_post = '/'; // $url_post['path'];
		} else {
			$u_post = parse_url( get_permalink( $post_id ) );
		}

		if ( 'localhost' == $u_post['host'] ) {
			$filter = 'ga:pagePath==/'; // .$u_post['path'];
		} else {
			$filter = 'ga:pagePath==' . $u_post['path'] . '';
			// $filter = 'ga:pagePath==' . $u_post['host'] . '/';
			$filter = apply_filters( 'analytify_page_path_filter', $filter, $u_post );
			// Url have query string incase of WPML.
			if ( isset( $u_post['query'] )  ) {
				$filter .= '?' . $u_post['query'];
			}
		}


		if ( '' == $start_date ) {

			$s_date = get_the_time( 'Y-m-d', $post->ID );
			if ( get_the_time( 'Y', $post->ID ) < 2005 ) {
				$s_date = '2005-01-01';
			}
		} else {
			$s_date = $start_date;
		}

		if ( '' == $end_date ) {
			$e_date = date( 'Y-m-d' );
		} else {
			$e_date = $end_date;
		}

		$Analytify_Email = $GLOBALS['WP_ANALYTIFY'];

		$_logo_id  = $Analytify_Email->settings->get_option( 'analytify_email_logo','wp-analytify-email' );
		if ( $_logo_id ) {
			$_logo_link_array =  wp_get_attachment_image_src( $_logo_id, array( 150, 150 ) );
			$logo_link = $_logo_link_array[0];
		} else {
			$logo_link = ANALYTIFY_IMAGES_PATH . "logo.png";
		}

		$message = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
			<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
					<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
							<meta name="viewport" content="width=device-width, initial-scale=1"/>
					<title>Analytify</title>
					<link href="https://fonts.googleapis.com/css?family=Roboto%7cRoboto+Slab:400,700" rel="stylesheet"/>
					<style type="text/css">
						@media screen and (max-width: 620px) {
								.main-table{
								width: 100% !important;
							}
						}
						@media screen and (max-width: 560px) {
							.box-table>tbody>tr>td{
								width: 100% !important;
								display: block !important;
								margin-bottom: 10px !important;
							}
							.session-table>table{
								display: block !important;
								width: 100% !important;
							}
							.session-table>table>tbody{
								display: block !important;
								width: 100% !important;
							}
							.session-table>table>tbody>tr{
								display: block !important;
								width: 96% !important;
								margin: 10px 2% 10px !important;
							}
							.os-table>td, .keywords-table>td{
								display: block;
								width: 100% !important;
							}
							.geographic-table>tbody>tr>td{
								display: block !important;
								width: 100% !important;
							}
							.user-data>table>tbody>tr>td{
								padding:10px !important;
							}
							.mobile-hide{
								display: none !important;
							}
							.main-table>tbody>tr>td{
								padding: 10px !important;
							}
							.user-data>table>tbody>tr>td img{
								margin-left: 0 !important;
							}
						}

					</style>
			</head>
			<body style="margin: 0;padding: 0; background: #f1f1f1; " bgcolor="#f1f1f1">
				<table cellpadding="0" cellspacing="0" border="0" width="100%" align="center" bgcolor="#f1f1f1">
					<tr>
						<td valign="top">
							<table cellpadding="0" cellspacing="0" border="0" width="600" align="center" class="main-table">
								<tr>
									<td style="padding: 22px 35px;">
										<table width="100%" cellpadding="0" cellspacing="0" align="center">
											<tr>
												<td align="left"><a href="'. $site_url .'"><img src="'. $logo_link .'" alt=""/></a></td>
												<td align="right" style="font: normal 14px \'Roboto\', Arial, Helvetica, sans-serif;">
												<font color="#848484">' . __( 'Your Analytics Report', 'wp-analytify-email' ) . '</font><br>
												<font color="#444444">' . $s_date . ' - ' . $e_date . '</font><br />
												<font color="#444444">'. get_the_title( $post_id ) .'</font>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								<tr>

									<td style="padding: 0 15px;">
										<table width="100%" cellpadding="0" cellspacing="0" align="center">';

						$selectd_stats = 	$Analytify_Email->settings->get_option( 'show_panels_back_end', 'wp-analytify-admin' );

						// General Stats.
						if ( is_array( $selectd_stats ) &&  in_array( 'show-overall-dashboard', $selectd_stats )  ) {

							$stats = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions,ga:users,ga:pageviews,ga:avgSessionDuration,ga:bounceRate,ga:percentNewSessions,ga:newUsers,ga:avgTimeOnPage', $s_date, $e_date, false, false, $filter );

							include ANALYTIFY_EMAIL_ROOT_PATH . 'views/general-stats-single.php';
							$message .= pa_email_include_single_general( $Analytify_Email, $stats, false, false );

						}

						// Geographic Stats
						if ( is_array( $selectd_stats ) && in_array( 'show-geographic-dashboard', 	$selectd_stats )  ) {

							$countries = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:country' , '-ga:sessions' , 'ga:country!=(not set);' . $filter, 5 );
							$cities = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:country,ga:city' , '-ga:sessions' , 'ga:city!=(not set);' . $filter, 5 );
							include ANALYTIFY_EMAIL_ROOT_PATH . 'views/geographic.php';
							$message .= pa_geopgraphic_lisiting( $Analytify_Email, $countries, $cities );

						}

						// System stats
						if ( is_array( $selectd_stats ) && in_array( 'show-system-stats', $selectd_stats )  ) {

							$browers = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:browser' , '-ga:sessions' , $filter, 5 );
							$operating_systems = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:operatingSystem' , '-ga:sessions' , 'ga:operatingSystem!=(not set);' . $filter, 5 );
							$mobile_phones = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:mobileDeviceBranding,ga:mobileDeviceModel' , '-ga:sessions' , 'ga:mobileDeviceModel!=(not set);ga:mobileDeviceBranding!=(not set);' . $filter, 5 );
							include ANALYTIFY_EMAIL_ROOT_PATH . 'views/system-stats.php';
							$message .= pa_system_stats( $Analytify_Email, $browers, $operating_systems, $mobile_phones );

						}


						// Keywords
						if ( is_array( $selectd_stats ) && in_array( 'show-keywords-dashboard', $selectd_stats )  ) {

							$keywords = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:keyword' , '-ga:sessions' , $filter, 5 );
							$refferals = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:source,ga:medium' , '-ga:sessions' , $filter, 5 );
							include ANALYTIFY_EMAIL_ROOT_PATH . 'views/keyword-referral.php';
							$message .= pa_keyword_referral( $Analytify_Email, $keywords, $refferals );

						}

						// Social Media
						if ( is_array( $selectd_stats ) && in_array( 'show-social-dashboard', $selectd_stats )  ) {

							$socials = $Analytify_Email->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date , 'ga:socialNetwork' , '-ga:sessions' , 'ga:socialNetwork!=(not set);' . $filter, 5 );
							include ANALYTIFY_EMAIL_ROOT_PATH . 'views/social-media.php';
							$message .= social_stats( $Analytify_Email, $socials );

						}

						$message .= '	</table>
																</td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</body>
										</html>';

		$emails = $Analytify_Email->settings->get_option( 'analytify_email_user_email','wp-analytify-email' );
		$emails_array = explode( ',' , $emails );

		$subject = 'Analytics for ' . get_the_title( $post_id ) ;

		$_from_name  = $Analytify_Email->settings->get_option( 'analytiy_from_name', 'wp-analytify-email' );
		$_from_name  = ! empty( $_from_name ) ? $_from_name : 'Analytify Notifications';
		$_from_email = $Analytify_Email->settings->get_option( 'analytiy_from_email', 'wp-analytify-email' );
		$_from_email = ! empty( $_from_email ) ? $_from_email : get_option( 'admin_email' );

		$headers = array(
			'From: '. $_from_name . ' <' . $_from_email . '>',
			'Content-Type: text/html; charset=UTF-8'
		);

		wp_mail( $emails_array , $subject, $message, $headers );
		wp_die();
	}

}

?>
